@@ -5,18 +5,20 @@ replist <- function(object, group = NULL, opt = FALSE, ...)
   if (length(group) != length(object)) stop("length of 'group' and 'object' must match!")   
   group <- as.factor(group)
   
-  splitVec <- split(1:length(object), group)
+  splitVec <- split(1:length(object), group)      
   nameVec <- sapply(object, function(x) x$names)
   nameVec <- split(nameVec, group)  
   
   repMod <- list()
   meanDATA <- list()
+  tempModList <- list()
   tempDATA <- NULL
   
   for (i in 1:length(splitVec)) {   
-   for (j in splitVec[[i]]) {
+   for (j in splitVec[[i]]) {      
     tempDATA <- rbind(tempDATA, object[[j]]$DATA)      
-   }
+   }  
+   tempModList[[i]] <- object[splitVec[[i]]]               
    repMod[[i]] <- tempDATA 
    meanFLUO <- tapply(tempDATA[, 2], as.factor(tempDATA[, 1]), function(x) mean(x, na.rm = TRUE))    
    uniqueCYC <- unique(tempDATA[, 1])
@@ -28,7 +30,7 @@ replist <- function(object, group = NULL, opt = FALSE, ...)
   
   finMod <- list()
   
-  for (i in 1:length(meanDATA)) {
+  for (i in 1:length(meanDATA)) {           
     flush.console()
     cat("Making model for replicates:", nameVec[[i]]) 
     meanMod <- try(pcrfit(meanDATA[[i]], 1, 2, model = object[[splitVec[[i]][1]]]$MODEL), silent = TRUE)
@@ -49,10 +51,12 @@ replist <- function(object, group = NULL, opt = FALSE, ...)
     
     finMod[[i]] <- fitObj
     finMod[[i]]$isReps <- TRUE
-    finMod[[i]]$names <- paste("group_", i, sep = "")
-  }
+    finMod[[i]]$names <- paste("group_", i, sep = "") 
+    finMod[[i]]$DATA <- repMod[[i]]
+    finMod[[i]]$modlist <- tempModList[[i]]     
+  }      
   class(finMod) <- c("modlist", "replist", "pcrfit")
   attr(finMod, "nlevels") <- nlevels(group)
-  attr(finMod, "nitems") <- length(group)/nlevels(group)
+  attr(finMod, "nitems") <- length(group)/nlevels(group)     
   return(finMod)
 }
\ No newline at end of file
